#
# spec file for package CastXML
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           CastXML
Version:        0.6.4
Release:        2.2
Summary:        C-family Abstract Syntax Tree XML Output
License:        Apache-2.0
URL:            https://github.com/CastXML/CastXML
Source0:        https://github.com/CastXML/%{name}/archive/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
Source1:        %{name}-rpmlintrc
# PATCH-FIX-UPSTREAM
Patch0:         0001-Port-to-LLVM-Clang-Git-release-18.x-as-of-2024-02-05.patch
BuildRequires:  clang-devel
BuildRequires:  cmake
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  python3-Sphinx
BuildRequires:  pkgconfig(libxml-2.0)
BuildRequires:  pkgconfig(zlib)

%description
CastXML is a C-family abstract syntax tree XML output tool.

%package devel
Summary:        C-family Abstract Syntax Tree XML Output

%description devel
CastXML is a C-family abstract syntax tree XML output tool.

%prep
%autosetup -p1

%build
%cmake -DCastXML_INSTALL_MAN_DIR:PATH=%{_mandir} \
       -DCastXML_INSTALL_DOC_DIR:PATH=%{_docdir}/%{name} \
       -DCLANG_LINK_CLANG_DYLIB:BOOL=ON \
       -DBUILD_TESTING:BOOL=ON \
       -DSPHINX_HTML:BOOL=ON \
       -DSPHINX_MAN:BOOL=ON

%cmake_build

%install
%cmake_install

# REMOVE FILES TO BE INSTALLED USING %%doc OR %%license
rm %{buildroot}%{_docdir}/%{name}/LICENSE

%fdupes %{buildroot}%{_datadir}/castxml/clang/include/

%check
%ctest

%files devel
%license LICENSE
%{_bindir}/castxml
%{_mandir}/man1/castxml.1%{?ext_man}
%{_datadir}/castxml/
%doc %{_docdir}/%{name}

%changelog
* Thu Mar 21 2024 Christophe Marin <christophe@krop.fr>
- Add upstream change:
  * 0001-Port-to-LLVM-Clang-Git-release-18.x-as-of-2024-02-05.patch
* Mon Jan 22 2024 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 0.6.4:
  * Improve simulated _Float## types to support glibc headers
    (gh#CastXML/CastXML#251).
* Fri Jan 19 2024 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 0.6.3:
  * No release notes.
* Sat Sep 30 2023 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 0.6.2:
  * Support LLVM/Clang 17.0.
* Sat Apr  1 2023 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 0.6.1:
  * test: Restore support for CMake <= 3.25 in test suite
- Changes from version 0.6.0:
  * Output:
  - Generate functions with rvalue-references in signatures.
  - Generate RValueReferenceType elements in castxml output
    format.
  - Add AutoType element for "auto" types that have not been
    deduced.
  - Add ElaboratedType elements with "qualifier=" attribute.
  - Add a "keyword=" attribute to ElaboratedType elements.
  - Forward complete output requests through ElaboratedType.
  - Explicitly guard empty struct name.
  - Avoid generating "init=" attribute for float128
    compatibility type.
  - Factor out helper to check for float128 compatibility decl.
  * RunClang: Detect -std=c++20 from --castxml-cc-{gnu,msvc} test:
  - Add case with Elaborated type due to qualified name.
  - Update assume_aligned case to suppress -Wundefined-inline
    warning.
  - Tolerate '-internal-*' flags after '-isystem' flags.
* Wed Dec 14 2022 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 0.5.1:
  * Bug fix: tests fail on 32-bit architectures
    (gh#CastXML/CastXML#232).
* Wed Dec  7 2022 Dirk Müller <dmueller@suse.com>
- update to version 0.5.0:
  * No release notes
* Sun Nov 27 2022 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 0.4.8:
  * No release notes.
* Sun Nov 20 2022 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 0.4.7:
  * No release notes.
* Thu Sep  1 2022 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 0.4.6:
  * No release notes.
- Use fdupes to link duplicate files.
- Add CastXML-rpmlintrc to suppress errors about empty files that
  are actually needed.
* Tue Mar  8 2022 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 0.4.5:
  * No release notes.
- Build tests, and run them as part of %%check section.
- New BuildRequires for tests: pkgconfig(libxml-2.0),
  pkgconfig(zlib).
* Tue Oct 26 2021 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 0.4.4:
  * RunClang: Tolerate GNU __attribute__((__malloc__)) with
    arguments [gh#CastXML/CastXML#204].
  * Test: Updates for LLVM/Clang 13.0.
* Thu Mar  4 2021 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 0.4.3:
  * Output: Account for multiple annotations
    [gh#CastXML/CastXML#194].
* Fri Jan 15 2021 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 0.4.2:
  * test: Fix expected output on 32-bit architectures
    (i686/armv7hl).
- Changes from version 0.4.1:
  * schema: allow 'mangled' attributes to be empty.
  * test: Tell Git to use LF newlines for test inputs.
  * test: Make Function-Argument-default-ns output more
    predictable.
  * Output: Generate Enumeration underlying integer type.
* Wed Jan 13 2021 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 0.4.0:
  * Port to LLVM/Clang Git master as of 2020-07-13.
  * test: Stabilize order of Field class implicits.
  * Output: Generate Comment elements for declaration doc
    comments.
  * Output: Add 'final' and 'override' attributes to virtual
    methods.
  * Output: Generate explicit deprecation attributes.
  * Output: Generate explicit annotation attributes.
  * doc,test: Add XML Schema definition for both output formats.
* Fri Aug 21 2020 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 0.3.6:
  * Detect: Factor out check for compiler builtin headers into
    helper function.
  * Detect: Fix GNU builtin include directory detection on
    aarch64.
* Thu Aug 20 2020 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 0.3.5:
  * Backport support for LLVM/Clang 11.0 to 0.3.x release series.
  * Detect: Add support for aarch64 architecture in target triple.
- Fix builds for openSUSE <= 1500 by passing
  CLANG_LINK_CLANG_DYLIB=ON for all oS versions.
* Sun May 17 2020 Atri Bhattacharya <badshah400@gmail.com>
- Initial package.
